Skip to contents

Defines the background class, which contains all characteristics of the setting in which agents will be simulated to walk. Currently consists of the shape of the simulated room and objects that are contained within the room.

Slots

shape

Object of a type that extends object-class defining the shape of the background. Importantly, the shape cannot be of the segment-class.

objects

List of objects of a type that extends object-class defining the objects that are present in the simulated room (e.g., tables and cabinets). Importantly, objects cannot be of the segment-class.

limited_access

List of objects of the segment-class which define the routes that can only be taken in one direction (see the documentation of segment-class).

precomputed_limited_access

List of non-penetrable objects based on the values of slot limited_access. Is not meant to be changed by the user, but is used as a slot to significantly speed up computations.

entrance

Numeric matrix specifying the location(s) of the entrance(s), where the first column denotes the x-coordinate and the second column the y-coordinate.

exit

Numeric matrix specifying the location(s) of the exit(s), where the first column denotes the x-coordinate and the second column the y-coordinate.