Skip to contents

Special case of the object-class defined through its center and radius.

Slots

center

Numeric vector denoting the center or position of the circle.

radius

Numeric denoting the radius of the circle.

forbidden

Numerical matrix containing the angles for which you cannot generate goals (in radians).

...

Slots shared with object-class.

See also

object-class, initialize-circle

Other objects: object-class, polygon-class, rectangle-class