Skip to contents

This function is a simple utility function to extract all objects from a given class from a list containing several of those.

Usage

find_class(class_name, lst)

Arguments

class_name

A string with the name of the class

lst

The list in which to search for these objects

Value

A list containing all instances of the class.