Skip to contents

An S4 Abstract Base Class to Represent Objects

Slots

id

Character denoting the name of the object.

moveable

Logical denoting whether the object can be moved from its position.

interactable

Logical indicating whether the object can be interacted with.