Skip to contents

Wrapper of the generate_parameters function that uses the provided arguments to visualize the distribution of parameter values under the current specifications.

Usage

plot_distribution(...)

Arguments

...

Arguments provided to the generate_parameters.

Value

Plotted histograms of the prior distribution of parameters under the provided specifications.