Skip to contents

Special case of the polygon-class, defined through its four sides and right angles.

Slots

center

Numeric vector denoting the coordinates of the center or position of the rectangle.

size

Numeric vector denoting the width and height of the rectangle.

orientation

Numeric indicating the orientation of the rectangle in radians.

...

Slots shared with the object-class and the polygon-class.