Skip to contents

An S4 Class to Represent the State

Slots

iteration

Numeric denoting the iteration number.

setting

Object of the background-class.

agents

List containing objects of the agent-class representing the agents that are currently walking around in the setting.

potential_agents

List containing objects of the agent-class representing agents that are waiting to enter the setting.

iteration_variables

Dataframe containing values for variables that control the simulation under the hood, such as max_agents.

variables

List of user-specified variables that can be used to control the simulation, see the fx argument of simulate

See also