Skip to contents

Use the inputted matrix to construct the covariance matrix for the parameters.

Usage

to_covariance(X)

Arguments

X

A d x d matrix containing the standard deviations of the parameters on the diagonal and the correlations between parameters off the diagonal.

Value

Covariance matrix