Defines the agent class, which contains all characteristics of an agent.
Some of these characteristics are time-independent (e.g., parameters and
set of goals) while others change during each time step in the simulation or
estimation (e.g., speed and orientation).
Slots
idCharacter that serves as an identifier for the agent.
centerNumerical vector of two elements denoting the current position of the agent (x and y coordinate).
radiusNumeric denoting the size of agent. As agents are circular, this is equal to the radius of the agent.
speedNumeric denoting the current speed of the agent (in m/sec).
orientationNumeric denoting the orientation of the agent (in degrees)
groupNumeric indicating the group to which the agent belongs. Influences the behavior of the agent through the social utility functions.
statusCharacter denoting the current status of the agent, or what they will be doing to make the next decision. Is one of "move" (the agent will move to another cell), "plan" (the agent will plan the route to their next goal), "reroute" (the agent will replan the route of their current goal), "reorient" (the agent will check other movement options), "completing goal" (the agent will interact with their goal), "exit" (the agent will exit the space), or "wait" (the agent will wait for another agent to finish their goal and step out of the way).
waiting_counterNumeric defining how long the agent will remain in the status "wait" once triggered. At the start of the waiting period is set to be equal to the number of iterations the other agent still has to interact with their goal plus 2.
cellNumeric denoting the cell the agent will move to.
current_goalObject of class
goal-classwhich represents the current goal of the agent.goalsList of goals the agent has to achieve. The current goal is not included in this list.
parametersDataframe containing the values of the parameters for the agent. Should contain all parameters relevant for the utility functions (use
predped::draw_parameters(1)for an example).colorCharacter denoting the color in which the agent should be plotted.
cell_centersNumeric matrix denoting the positions that the agent may move to at a particular iteration.
utility_variablesData.frame precomputed containing values for all the variables relevant to compute the utilities.
See also
circle-class,
goal-class,
object-class,
cell,
current_goal,
goals,
group,
id,
orientation,
parameters
position,
size,
speed,
status,
waiting_counter,
initialize-agent