Defines the background class, which contains all characteristics of
the setting in which agents will be simulated to walk. Currently consists of
the shape of the simulated room and objects that are contained within the
room.
Slots
shapeObject of a type that extends
object-classdefining the shape of the background. Importantly, the shape cannot be of thesegment-class.objectsList of objects of a type that extends
object-classdefining the objects that are present in the simulated room (e.g., tables and cabinets). Importantly, objects cannot be of thesegment-class.limited_accessList of objects of the
segment-classwhich define the routes that can only be taken in one direction (see the documentation ofsegment-class).precomputed_limited_accessList of non-penetrable objects based on the values of slot
limited_access. Is not meant to be changed by the user, but is used as a slot to significantly speed up computations.entranceNumeric matrix specifying the location(s) of the entrance(s), where the first column denotes the x-coordinate and the second column the y-coordinate.
exitNumeric matrix specifying the location(s) of the exit(s), where the first column denotes the x-coordinate and the second column the y-coordinate.
See also
circle-class,
object-class,
polygon-class,
rectangle-class,
segment-class,
entrance,
exit,
limited_access,
objects,
shape,
initialize-background,