Special case of the object-class defined through its
center and radius.
Slots
centerNumeric vector denoting the center or position of the circle.
radiusNumeric denoting the radius of the circle.
forbiddenNumerical matrix containing the angles for which you cannot generate goals (in radians).
...Slots shared with
object-class.
See also
object-class,
initialize-circle
Other objects:
object-class,
polygon-class,
rectangle-class