Rcpp version of the compute_utility_variables function.
Usage
compute_utility_variables_rcpp(
agent,
state,
background,
agent_specifications,
centers,
check_original
)Arguments
- agent
Object of the
agent-class.- state
Object of the
state-class.- background
Object of the
background-class.- agent_specifications
List created by the
create_agent_specificationsfunction. Contains all information of all agents within the currentstateand allows for the communication between thepredpedsimulation functions and them4mautility functions.- centers
Numerical matrix containing the coordinates at each position the object can be moved to. Should have one row for each cell.
- check_original
Logical matrix of dimensions 11 x 3 denoting whether an agent can move to a given cell (
TRUE) or not (FALSE).
Value
Data.frame containing all of the needed variables to be able to compute the values of the utility functions.
See also
simulate,
simulate.state,
update-agent,
update,
update_position,
update