Defines the goal class, which contains all characteristics of a goal that
the agents can pursue.
Slots
idCharacter that serves as an identifier for the goal.
positionNumerical vector denoting the position of the goal.
pathNumerical matrix of size n x 2 denoting the different intermediate path points between an agent and a goal. In effect defines which path the agent will take to move towards the goal.
busyLogical denoting whether the goal is currently being interacted with.
doneLogical denoting whether a goal has been completed.
counterNumeric denoting the number of time steps the agent should interact with the goal before the goal has been completed.