Constructor for the polygon-class
Usage
# S4 method for class 'polygon'
initialize(.Object, points, clock_wise = TRUE, forbidden = numeric(0), ...)Arguments
- .Object
For this class, should be left unspecified (see Example).
- points
Numerical matrix containing the coordinates that make up the polygon.
- clock_wise
Logical denoting whether the coordinates in
pointsare defined in clockwise (TRUE) or counter-clockwise fashion (FALSE). Defaults toTRUE.- forbidden
Numerical vector containing the indices of those edges that cannot be used to generate goals on. Note that edges are created based on the
pointsof the object. Defaults to an empty vector, making all edges worthy of goal generation.- ...
Additional arguments passed to
initialize-object.
Value
Object of the polygon-class
See also
object-class
polygon-class
initialize-object