Constructor for the segment-class
Arguments
- .Object
The class you wish to initialize. See the example for how you can initialize an instance of a class within this package.
- from
Numeric vector denoting the coordinates of the where the segment begins.
- to
Numeric vector denoting the coordinates of the where the segment ends.
- ...
Additional arguments passed to
initialize-object.
Value
Object of the segment-class
See also
segment-class,
object-class,
initialize-object