Rcpp version of line_line_intersection. Computes the between several segments. Is a vectorized function with minimal loss of time when the number of segments to test increases.
Source:R/RcppExports.R
line_line_intersection_rcpp.RdRcpp version of line_line_intersection. Computes the between several segments. Is a vectorized function with minimal loss of time when the number of segments to test increases.