An S4 Abstract Base Class to Represent Objects
Slots
idCharacter denoting the name of the object.
moveableLogical denoting whether the object can be moved from its position.
interactableLogical indicating whether the object can be interacted with.
See also
circle-class,
polygon-class,
rectangle-class,
segment-class
Other objects:
circle-class,
polygon-class,
rectangle-class