Special case of the polygon-class, defined through its
four sides and right angles.
Slots
centerNumeric vector denoting the coordinates of the center or position of the rectangle.
sizeNumeric vector denoting the width and height of the rectangle.
orientationNumeric indicating the orientation of the rectangle in radians.
...Slots shared with the
object-classand thepolygon-class.
See also
circle-class,
object-class,
polygon-class
Other objects:
circle-class,
object-class,
polygon-class