An S4 Class to Represent the State
Slots
iterationNumeric denoting the iteration number.
settingObject of the
background-class.agentsList containing objects of the
agent-classrepresenting the agents that are currently walking around in thesetting.potential_agentsList containing objects of the
agent-classrepresenting agents that are waiting to enter thesetting.iteration_variablesDataframe containing values for variables that control the simulation under the hood, such as
max_agents.variablesList of user-specified variables that can be used to control the simulation, see the
fxargument ofsimulate
See also
agents,
initialize-state,
iteration,
potential_agents,
setting