R/parameters.R
to_covariance.Rd
Use the inputted matrix to construct the covariance matrix for the parameters.
to_covariance(X)
A d x d matrix containing the standard deviations of the parameters on the diagonal and the correlations between parameters off the diagonal.
Covariance matrix
generate_parameters, plot_distribution, to_bounded, to_unbounded
generate_parameters
plot_distribution
to_bounded
to_unbounded