Update the current state by updating all of the agents that are contained in it.
Usage
# S4 method for class 'state'
update(object, time_step = 0.5, stay_stopped = TRUE, cpp = TRUE, ...)Arguments
- object
Object of the
state-class.- time_step
Numeric denoting the number of seconds each discrete step in time should mimic. Defaults to
0.5, or half a second.- stay_stopped
Logical denoting whether agents will predict others that are currently not moving to remain immobile in the next iteration. Defaults to
TRUE.- cpp
Logical denoting whether to use the Rcpp alternatives for several of the lower-level functions (
TRUE) or whether to use the R alternatives instead (FALSE). Defaults toTRUE.- ...
Additional arguments passed to
update-agent.
Value
Object of the state-class.
See also
create_agent_specifications,
simulate,
simulate.state,
update-agent