Compute the utilities with all utility variables known
Source:R/utility_model.R
utility-data.frame.RdThis function uses the values of the relevant variables used as input in the utility functions to derive the utility for each of the different moving options.
Arguments
- object
Dataframe containing all of the needed information to compute the utilities. Typically output of the
compute_utility_variablesfunction.- parameters
Dataframe containing the parameters of the agent. Should conform to the naming conventions mentioned in
params_from_csv.- cpp
Logical denoting whether to use the Rcpp version of the function (
TRUE) or the R version (FALSE). Defaults toTRUE.
See also
simulate,
simulate.state,
update-agent,
update,
utility-agent,
compute_utility_variables,
params_from_csv,
update_position