This function is the Rcpp equivalent of utility-agent. It
takes in a dataframe containing all of the relevant values for computing the
utility, as well as a dataframe containing the parameters. Heavily depends
on the m4ma package.
Arguments
- data
Dataframe containing all of the needed information to compute the utilities. Typically output of the
compute_utility_variablesfunction.- parameters
Dataframe containing the parameters of the agent. Should conform to the naming conventions mentioned in
params_from_csv.
See also
simulate,
simulate.state,
update-agent,
update,
utility-agent,
compute_utility_variables,
params_from_csv,
update_position